@@ -100,6 +100,6 @@ def get_text(time: Union[datetime, str, int]):
     return "".join(reply)
 
 
-week_day_strs = "一二三四五六日"
-re_week = rf"(?:周|星期)([\d{week_day_strs}])"
+week_day_strs = "一二三四五六日天末"
+re_week = rf"(?<!这个)(?<!这|本)(?:周|星期)([\d{week_day_strs}])"
 time_format = "%Y-%m-%d %H:%M:%S"
